/*! 
    \file skysphere.h
    \brief Definition of the Skysphere, that handles the Display of an atmosphere of orxonox.

    A SkySphere is always centered at the current working Camera, and will only obey the cameras
    movment but not its rotation.

    \todo self-rotation
    \todo handle reference to parent-object
*/

#ifndef _SKYSPHERE_H
#define _SKYSPHERE_H

/* INCLUDES */
#include "p_node.h"

/* FORWARD DEFINITION */
class Material;
class Vector;

//! A Class to handle a SkySphere
class Skysphere: public PNode 
{
 private: 
  GLUquadricObj *sphereObj;
  Vector sphereCenter; //!< Center of the Skysphere
  Material *sky;       //!< A Material for the Sky
  
 public:
  Skysphere();
  Skysphere(char* fileName);
  ~Skysphere();

  void updatePosition(Vector sphereCenter);
  void draw();

 private:
  void initialize(char* fileName);  
};

#endif


